#!/bin/bash
#
# source: http://downloads.sourceforge.net/project/hplip/hplip/3.9.8/hplip-3.9.8.tar.gz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft="hplip"
softversion="3.9.8"
arch="i486"
cpu="i686"
packageversion="62.3"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src
cat $buildir/hplip-hpcups-reorder.patch | patch -p1 --verbose
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

# Fix udev rules for current versions of udev
sed -i 's/SYSFS/ATTR/g' data/rules/*.rules
# Fix ownership in udev rules file
sed -i 's%OWNER="lp"%OWNER="root"%g' data/rules/*.rules

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --enable-pp-build \
  --enable-new-hpcups \
  --disable-cups-drv-install \
  --enable-foomatic-rip-hplip-install=no \
  --enable-qt4 \
  --with-hpppddir=/usr/share/cups/model/HP \
  --with-docdir=/usr/doc/$soft-$softversion \
  --with-drvdir=/usr/share/cups/drv/hp

make j2
make install DESTDIR=$dest rulesdir=/lib/udev/rules.d

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

rm -rf $dest/etc/sane.d
rm $dest/usr/lib/cups/filter/hpcups
rm $dest/usr/share/cups/model/HP/hp-*.gz

# make hp-fax utils in the zenwalk menu
cat << "EOF" > $dest/usr/share/applications/hp-fab.desktop
[Desktop Entry]
Categories=Application;Office;
Comment=A simple fax address book for HPLIP
Exec=/usr/bin/hp-fab
GenericName=Fax Address Book Application
Icon=/usr/share/hplip/data/images/32x32/fab.png
Name=HP Fax Address Book
Terminal=false
Type=Application
EOF

cat << "EOF" > $dest/usr/share/applications/hp-sendfax.desktop
[Desktop Entry]
Categories=Application;Office;
Comment=Utility for sending faxes with HP's multi-function devices
Exec=/usr/bin/hp-sendfax
GenericName= Sending Faxes Application
Icon=/usr/share/hplip/data/images/32x32/fax_machine.png
Name=HP Sendfax
Terminal=false
Type=Application
EOF

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler----------------------------------------------------------|
hplip: hplip - HP Print, Scan and Fax support for Linux
hplip:
hplip: HPLIP (Hewlett-Packard Linux Imaging & Printing) is an HP-developed
hplip: solution for printing, scanning, and faxing with HP inkjet and laser 
hplip: based printers in Linux. The HPLIP project provides printing support for
hplip: 1,686 printer models, including Deskjet, Officejet, Photosmart, PSC
hplip: (Print Scan Copy), Business Inkjet, LaserJet, Edgeline MFP, and LaserJet
hplip: MFP. (Note: Not all models are currently supported. See Supported
hplip: Printers for more information.)
hplip:
hplip:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5